#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-ant-xml
version:              1.1.8
visibility:           public
id:                   tasty-ant-xml-1.1.8-9YS1Wok5AUA8TzlbomGp72
key:                  tasty-ant-xml-1.1.8-9YS1Wok5AUA8TzlbomGp72
license:              BSD-3-Clause
copyright:            Oliver Charles 2013
maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-ant-xml
synopsis:             Render tasty output to XML for Jenkins
description:
    A tasty ingredient to output test results in XML, using the Ant schema. This XML can be consumed by the Jenkins continuous integration framework.

category:             Testing
abi:                  42098cf43953e093a7bac4d8479d0454
exposed:              True
exposed-modules:      Test.Tasty.Runners.AntXML
import-dirs:          /usr/lib/ghc-8.10.5/site-local/tasty-ant-xml-1.1.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tasty-ant-xml-1.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tasty-ant-xml-1.1.8
hs-libraries:         HStasty-ant-xml-1.1.8-9YS1Wok5AUA8TzlbomGp72
depends:
    base-4.14.2.0 containers-0.6.4.1 directory-1.3.6.0 filepath-1.4.2.1
    generic-deriving-1.14-15FNbtSLqa6F3AOxs0dmDl ghc-prim-0.6.1
    mtl-2.2.2 stm-2.5.0.1 tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV
    tasty-1.4.1-o6GqK7uhQW6VZVrPJnWQG transformers-0.5.6.2
    xml-1.3.14-9Z9ZesgMbrVGnsSsWvOX4O

haddock-interfaces:
    /usr/share/doc/haskell-tasty-ant-xml/html/tasty-ant-xml.haddock

haddock-html:         /usr/share/doc/haskell-tasty-ant-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

